@@ -1,6 +1,6 @@
 package XML::Struct::Writer;
-# ABSTRACT: Write XML data structures as XML stream
-our $VERSION = '0.11'; # VERSION
+# ABSTRACT: Write XML data structures to XML streams
+our $VERSION = '0.12'; # VERSION
 
 use strict;
 use Moo;
@@ -98,15 +98,16 @@ sub writeEnd {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
 
-XML::Struct::Writer - Write XML data structures as XML stream
+XML::Struct::Writer - Write XML data structures to XML streams
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -196,7 +197,7 @@ can be passed, so C<< $writer->writeEnd($root) >> is equivalent to:
 
 =head1 CONFIGURATION
 
-=over 4
+=over
 
 =item C<handler>
 
@@ -215,8 +216,8 @@ instead of
 
 =item encoding
 
-Sets the encoding form I<known> handlers. By now this only affects the encoding
-of
+Sets the encoding for handlers that support an explicit encoding. Set to UTF-8
+by default.
 
 =back
 
@@ -225,7 +226,7 @@ of
 A SAX handler, as used by this module, is expected to implement the following
 methods (two of them are optional):
 
-=over 4
+=over
 
 =item xml_decl( { Version => $version, Encoding => $encoding } )
 
@@ -265,7 +266,7 @@ from this methods. Handlers do not need to implement this method.
 Using a streaming SAX handler, such as L<XML::SAX::Writer>,
 L<XML::Genx::SAXWriter>, L<XML::Handler::YAWriter>, and possibly L<XML::Writer>
 should be more performant for serialization. Examples of other modules that
-receive SAX events include L<XML::STX>, L<XML::SAX::SimpleDispatcher>,
+receive SAX events include L<XML::STX>, L<XML::SAX::SimpleDispatcher>, and
 L<XML::SAX::Machines>,
 
 =encoding utf8
@@ -282,4 +283,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
